@@ -373,8 +373,13 @@ sub op_builtin_uri {
     goto $_[0]->{ code }->[ ++$_[0]->{ pc } ]->{ exec_code };
 }
 
-sub op_builtin_ref {
-    $_[0]->{sa} = ref($_[0]->{sa});
+sub op_builtin_is_array_ref {
+    $_[0]->{sa} = ref($_[0]->{sa}) eq 'ARRAY';
+    goto $_[0]->{ code }->[ ++$_[0]->{ pc } ]->{ exec_code };
+}
+
+sub op_builtin_is_hash_ref {
+    $_[0]->{sa} = ref($_[0]->{sa}) eq 'HASH';
     goto $_[0]->{ code }->[ ++$_[0]->{ pc } ]->{ exec_code };
 }
 
