@@ -18,9 +18,19 @@ our @EXPORT_OK = qw(
     is_int any_in
     read_around
     make_error
-    $STRING $NUMBER $DEBUG
+    $DEBUG
+    $STRING $NUMBER
 );
 
+our $DEBUG;
+defined($DEBUG) or $DEBUG = $ENV{XSLATE} || '';
+
+our $DisplayWidth = 76;
+if($DEBUG =~ /display_width=(\d+)/) {
+    $DisplayWidth = $1;
+}
+
+
 my $dquoted = qr/" (?: \\. | [^"\\] )* "/xms; # " for poor editors
 my $squoted = qr/' (?: \\. | [^'\\] )* '/xms; # ' for poor editors
 our $STRING  = qr/(?: $dquoted | $squoted )/xms;
@@ -37,14 +47,6 @@ our $NUMBER  = qr/ (?:
         )?)
     )/xms;
 
-our $DEBUG;
-defined($DEBUG) or $DEBUG = $ENV{XSLATE} || '';
-
-our $DisplayWidth = 76;
-if($DEBUG =~ /display_width=(\d+)/) {
-    $DisplayWidth = $1;
-}
-
 require Text::Xslate; # load XS stuff
 
 sub mark_raw;    # XS
